function [fx0,fy0,type] = zf(fx,fy,wgt)
% ZF gets current field points and sets new field points in ZEMAX 
%
%   function function [fx0,fy0] = zf(fx,fy)
%
%   INPUT:  fx,fy = sets new field data
%               -- two column input for fx is interpreted as [fx fy] data
%               -- fx only input (all integers) sets those current field points, removing
%               all others
%           NOTE: units should be absolute (i.e. in degrees or mm)
%           wgt = weights for field points
%
%   OUTPUT  fx0 fy0 = current field points defined in zemax 
%               -- if only fx0 ouput is requested, [fx0 fy0] is returned
%           NOTE: output units are absolute (i.e. degrees / mm)
%
%   See also ZW, ZC
%

if nargin>0 % set new fields in ZEMAX
    if size(fx,2) == 2  %2 column input data
        fy = fx(:,2); fx = fx(:,1); 
    elseif nargin<2  %create fy data if none given
        fy = 0*fx; 
    end
    if nargin<3, wgt = fx*0+1; end %default wgt values = 1
    zreq(['SetField,0,' int2str(type) ',' int2str(length(fx))]); %set number of fields
    for i=1:length(fx)
        zreq(['SetField,' int2str(i) ',' num2str(fx(i)) ',' num2str(fy(i)) ',' num2str(wgt(i))]); %set field data
    end
    zpush;
else % get current fields in ZEMAX
    zpull;
    [type,numf,xmax,ymax] = strread(zreq('GetField,0'),'%d%f%f%f','delimiter',',');
    for i=1:numf
        [fx0(i),fy0(i),fwt(i),vdx(i),vdy(i),vcx(i),vcy(i),van(i)] = ...
            strread(zreq(['GetField,' int2str(i)]),'%f%f%f%f%f%f%f%f','delimiter',',');
    end
end

if nargout<2
    fx0 = [fx0' fy0'];
end

% Copyright  2005 United States Government as represented by the Administrator 
% of the National Aeronautics and Space Administration.  No copyright is claimed 
% in the United States under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     