function [opd,mask] = zopd(nrd,f,w,c,s)
% ZOPD gets opd data from ZEMAX
% function [opd,mask] = zopd(nrd,f,w,c,s)
% INPUT:    nrd = # rays across pupil diameter (pow2: 32,64,128,etc.)
%           f = field number, default = 1
%           w = wavelength, default wavelength number = 1
%           c = configuration number, default = 1
%           s = surface, default = image (last surface), currently not
%               available
% OUTPUT:   opd = optical path differenc data
%           mask = pupil function

if nargin<1, nrd=64; end
if nargin<2, f=1; end
if nargin<3, w=1; end
if nargin<4, c=1; end
if nargin<5, s=0; end %default to image, currently not available

zc(c); %set configuration

if      nrd<=32,    samp = 1;
elseif  nrd<=64,    samp = 2;
elseif  nrd<=128,   samp = 3;
elseif  nrd<=256,   samp = 4;
elseif  nrd<=512,   samp = 5;
elseif  nrd<=1024,  samp = 6;
elseif  nrd<=2048,  samp = 7;
elseif  nrd<=4096,  samp = 8;
else                samp = 9;
end

%set appropriate settings prior to analysis
pathfilename = [cd '\zopd.txt'];
settingsfilename = [cd '\wfm.cfg'];
if ~exist(settingsfilename,'file'),  %ensure a settings file exists prior to changing
    cmd = [ 'GetTextFile,"' pathfilename '",Wfm,"' settingsfilename '",0' ];
    zreq(cmd);
end
zreq(['ModifySettings,"' settingsfilename '",WFM_SAMP,' int2str(samp)]);
zreq(['ModifySettings,"' settingsfilename '",WFM_FIELD,' int2str(f)]);
zreq(['ModifySettings,"' settingsfilename '",WFM_WAVE,' int2str(w)]);
% As of 2007.08.17, other options are not available at this time
% zreq(['ModifySettings,"' settingsfilename '",WFM_SURFACE,' int2str(s)]);
zpush;

cmd = [ 'GetTextFile,"' pathfilename '",Wfm,"' settingsfilename '",1' ];
zreq(cmd);

pause(samp/2); %delay to allow file to write
opd = textread(pathfilename,'%f','headerlines',16); % Read from file written to disk by Zemax
gridsize = sqrt(length(opd));
opd = reshape(opd,gridsize,gridsize); % Restructure the array to square
opd = rot90(opd); 
mask = opd~=0;

if nargout<1
    figure, imagesc(opd), axis image;
    rmsopd = std(opd(mask));
    title(['OPD for field # ' int2str(f) ', wavelength # ' int2str(w)]);
    xlabel(['RMS WFE = ' num2str(rmsopd)]);
    opd = rmsopd; %output RMS WFE value
end

% Copyright  2005 United States Government as represented by the Administrator 
% of the National Aeronautics and Space Administration.  No copyright is claimed 
% in the United States under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     