function out = zopen(pathfilename,append)
% ZOPEN loads a new lens in ZEMAX
% function out = zopen(pathfilename)
% INPUT:    pathfilename = full path of new file to load, default = GUI
%           append = 1 if append to current lens desired, default = 0 (no)
% OUTPUT:   out = 0 if success, -999 if failure

if nargin<1, %no input path given lens file
    [filename,pathname] = uigetfile({'*.zmx', 'Zemax Files (*.zmx)'},'Pick a lens file'); 
    if isequal(filename,0) || isequal(pathname,0), disp('Open file cancelled.'), return, end
    pathfilename = [pathname filename];
end
if nargin<2, append = 0; end

out = zreq(['LoadFile,' pathfilename ',' int2str(append)]);

if out(1)=='0' %output from Zemax is text
    zpush;
else
    disp('Load file failed!');
end

% Copyright  2005 United States Government as represented by the Administrator 
% of the National Aeronautics and Space Administration.  No copyright is claimed 
% in the United States under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     