function [w0,ww0,primary0] = zw(w,ww,primary)
% ZW gets current wavelengths and weights and sets new ones in ZEMAX 
%
%   function [w0,ww0,primary] = zw(w,ww)
%
%   INPUT:  w = sets new wavelengths, units = um
%           ww = sets new weights
%
%   OUTPUT  w0  = current wavelengths, units = um
%           ww0 = current wavelength weights 
%
%   See also ZS, ZF, ZC
%

if nargin>0 % set new wavelengths if entered
    if nargin<2, ww = w*0 + 1; end %default weight = 1
    if nargin<3, primary = 1; end %default primary = 1
    [primary0,numw] = strread(zreq(['SetWave,0,' int2str(primary) ',' int2str(length(w))]),'%d%f','delimiter',',');
    for i=1:numw
        [w0(i),ww0(i)] = strread(zreq(['SetWave,' int2str(i) ',' num2str(w(i)) ',' num2str(ww(i))]) ,'%f%f','delimiter',',');
    end
    zpush;
else  % get current wavelengths
    [primary0,numw] = strread(zreq('GetWave,0'),'%d%f','delimiter',',');
    for i=1:numw
        [w0(i),ww0(i)] = strread(zreq(['GetWave,' int2str(i)]),'%f%f','delimiter',',');
    end
end

% Copyright  2005 United States Government as represented by the Administrator 
% of the National Aeronautics and Space Administration.  No copyright is claimed 
% in the United States under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     